package java.sql;

import java.util.concurrent.Executor;
import java.util.Properties;
import java.util.Map;

public interface Connection extends Wrapper, AutoCloseable
{
    public static final int TRANSACTION_NONE = 0;
    public static final int TRANSACTION_READ_UNCOMMITTED = 1;
    public static final int TRANSACTION_READ_COMMITTED = 2;
    public static final int TRANSACTION_REPEATABLE_READ = 4;
    public static final int TRANSACTION_SERIALIZABLE = 8;
    
    public abstract Statement createStatement() throws SQLException;
    
    public abstract PreparedStatement prepareStatement(String p0) throws SQLException;
    
    public abstract CallableStatement prepareCall(String p0) throws SQLException;
    
    public abstract String nativeSQL(String p0) throws SQLException;
    
    public abstract void setAutoCommit(boolean p0) throws SQLException;
    
    public abstract boolean getAutoCommit() throws SQLException;
    
    public abstract void commit() throws SQLException;
    
    public abstract void rollback() throws SQLException;
    
    public abstract void close() throws SQLException;
    
    public abstract boolean isClosed() throws SQLException;
    
    public abstract DatabaseMetaData getMetaData() throws SQLException;
    
    public abstract void setReadOnly(boolean p0) throws SQLException;
    
    public abstract boolean isReadOnly() throws SQLException;
    
    public abstract void setCatalog(String p0) throws SQLException;
    
    public abstract String getCatalog() throws SQLException;
    
    public abstract void setTransactionIsolation(int p0) throws SQLException;
    
    public abstract int getTransactionIsolation() throws SQLException;
    
    public abstract SQLWarning getWarnings() throws SQLException;
    
    public abstract void clearWarnings() throws SQLException;
    
    public abstract Statement createStatement(int p0, int p1) throws SQLException;
    
    public abstract PreparedStatement prepareStatement(String p0, int p1, int p2) throws SQLException;
    
    public abstract CallableStatement prepareCall(String p0, int p1, int p2) throws SQLException;
    
    public abstract Map<String, Class<?>> getTypeMap() throws SQLException;
    
    public abstract void setTypeMap(Map<String, Class<?>> p0) throws SQLException;
    
    public abstract void setHoldability(int p0) throws SQLException;
    
    public abstract int getHoldability() throws SQLException;
    
    public abstract Savepoint setSavepoint() throws SQLException;
    
    public abstract Savepoint setSavepoint(String p0) throws SQLException;
    
    public abstract void rollback(Savepoint p0) throws SQLException;
    
    public abstract void releaseSavepoint(Savepoint p0) throws SQLException;
    
    public abstract Statement createStatement(int p0, int p1, int p2) throws SQLException;
    
    public abstract PreparedStatement prepareStatement(String p0, int p1, int p2, int p3) throws SQLException;
    
    public abstract CallableStatement prepareCall(String p0, int p1, int p2, int p3) throws SQLException;
    
    public abstract PreparedStatement prepareStatement(String p0, int p1) throws SQLException;
    
    public abstract PreparedStatement prepareStatement(String p0, int[] p1) throws SQLException;
    
    public abstract PreparedStatement prepareStatement(String p0, String[] p1) throws SQLException;
    
    public abstract Clob createClob() throws SQLException;
    
    public abstract Blob createBlob() throws SQLException;
    
    public abstract NClob createNClob() throws SQLException;
    
    public abstract SQLXML createSQLXML() throws SQLException;
    
    public abstract boolean isValid(int p0) throws SQLException;
    
    public abstract void setClientInfo(String p0, String p1) throws SQLClientInfoException;
    
    public abstract void setClientInfo(Properties p0) throws SQLClientInfoException;
    
    public abstract String getClientInfo(String p0) throws SQLException;
    
    public abstract Properties getClientInfo() throws SQLException;
    
    public abstract Array createArrayOf(String p0, Object[] p1) throws SQLException;
    
    public abstract Struct createStruct(String p0, Object[] p1) throws SQLException;
    
    public abstract void setSchema(String p0) throws SQLException;
    
    public abstract String getSchema() throws SQLException;
    
    public abstract void abort(Executor p0) throws SQLException;
    
    public abstract void setNetworkTimeout(Executor p0, int p1) throws SQLException;
    
    public abstract int getNetworkTimeout() throws SQLException;
}
